// @ts-check
const DAY_IN_MILISECONDS = 24 * 60 * 60 * 1000;

// Gets the string with the TimeZOne being used
const getTZ = () => Intl.DateTimeFormat().resolvedOptions().timeZone;

// Adds a number of days to a JavaScript Date
const addDaysToDate = (date, noDays) => {
  return new Date(date.getTime() + noDays * DAY_IN_MILISECONDS);
};

// Returns the days beetween two JavaScript dates
const daysBetween = (starts, ends) =>
  Math.round(Math.abs((starts - ends) / DAY_IN_MILISECONDS));

// Given a JavaScript Date, returns a "DD/MM/YYYY a las hh:mm" formated string
const toEvent = date => `${toDDMMYYYY(date)} a las ${toHHMM(date)}`;

// Given a JavaScript Date, returns a "hh:mm" formated string
const toHHMM = date => `${getHoras(date)}:${getMinutos(date)}`;

// Given a JavaScript Date, returns a "hh:mm:ss" formated string
const toHHMMSS = date => `${toHHMM(date)}:${getSegundos(date)}`;

// Given a JavaScript Date, returns a "DD/MM/YYYY" formated string
const toDDMMYYYY = date => `${getDia(date)}/${getMes(date)}/${getAnio(date)}`;

// Given a JavaScript Date, returns a "YYYYDDDD-hhmmss" formated string
const toFileName = date =>
  `${getAnio(date)}${getMes(date)}${getDia(date)}-${getHoras(date)}${getMinutos(
    date
  )}${getSegundos(date)}`;

// -------------------- Funciones auxiliares ------------------------

const getDia = date => {
  var dia = date.getDate();
  if (dia < 10) {
    dia = '0' + dia;
  }
  return dia;
};

const getMes = date => {
  var mes = date.getMonth() + 1;
  if (mes < 10) {
    mes = '0' + mes;
  }
  return mes;
};

const getAnio = date => date.getFullYear();

const getHoras = date => {
  var horas = date.getHours();
  if (horas < 10) {
    horas = '0' + horas;
  }
  return horas;
};

const getMinutos = date => {
  var minutos = date.getMinutes();
  if (minutos < 10) {
    minutos = '0' + minutos;
  }
  return minutos;
};

const getSegundos = date => {
  var segundos = date.getSeconds();
  if (segundos < 10) {
    segundos = '0' + segundos;
  }
  return segundos;
};

module.exports = {
  getTZ,
  addDaysToDate,
  daysBetween,
  toEvent,
  toFileName,
  toDDMMYYYY,
  toHHMM,
  toHHMMSS
};
